==> openshift-model-miscellaneous-5.12.4-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageS3Builder.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ImageRegistryConfigStorageS3Builder extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3FluentImpl<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Builder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Builder>{
  public ImageRegistryConfigStorageS3Builder() {
    this(false);
  }
  public ImageRegistryConfigStorageS3Builder(java.lang.Boolean validationEnabled) {
    this(new ImageRegistryConfigStorageS3(), validationEnabled);
  }
  public ImageRegistryConfigStorageS3Builder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent<?> fluent) {
    this(fluent, false);
  }
  public ImageRegistryConfigStorageS3Builder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ImageRegistryConfigStorageS3(), validationEnabled);
  }
  public ImageRegistryConfigStorageS3Builder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3 instance) {
    this(fluent, instance, false);
  }
  public ImageRegistryConfigStorageS3Builder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3 instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBucket(instance.getBucket()); 
    fluent.withCloudFront(instance.getCloudFront()); 
    fluent.withEncrypt(instance.getEncrypt()); 
    fluent.withKeyID(instance.getKeyID()); 
    fluent.withRegion(instance.getRegion()); 
    fluent.withRegionEndpoint(instance.getRegionEndpoint()); 
    fluent.withVirtualHostedStyle(instance.getVirtualHostedStyle()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageRegistryConfigStorageS3Builder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3 instance) {
    this(instance,false);
  }
  public ImageRegistryConfigStorageS3Builder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3 instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withBucket(instance.getBucket()); 
    this.withCloudFront(instance.getCloudFront()); 
    this.withEncrypt(instance.getEncrypt()); 
    this.withKeyID(instance.getKeyID()); 
    this.withRegion(instance.getRegion()); 
    this.withRegionEndpoint(instance.getRegionEndpoint()); 
    this.withVirtualHostedStyle(instance.getVirtualHostedStyle()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3 build() {
    ImageRegistryConfigStorageS3 buildable = new ImageRegistryConfigStorageS3(fluent.getBucket(),fluent.getCloudFront(),fluent.getEncrypt(),fluent.getKeyID(),fluent.getRegion(),fluent.getRegionEndpoint(),fluent.getVirtualHostedStyle());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryConfigStorageS3Builder that = (ImageRegistryConfigStorageS3Builder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.6.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageS3Builder.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ImageRegistryConfigStorageS3Builder extends ImageRegistryConfigStorageS3FluentImpl<ImageRegistryConfigStorageS3Builder> implements VisitableBuilder<ImageRegistryConfigStorageS3,ImageRegistryConfigStorageS3Builder>{
  public ImageRegistryConfigStorageS3Builder() {
    this(false);
  }
  public ImageRegistryConfigStorageS3Builder(Boolean validationEnabled) {
    this(new ImageRegistryConfigStorageS3(), validationEnabled);
  }
  public ImageRegistryConfigStorageS3Builder(ImageRegistryConfigStorageS3Fluent<?> fluent) {
    this(fluent, false);
  }
  public ImageRegistryConfigStorageS3Builder(ImageRegistryConfigStorageS3Fluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ImageRegistryConfigStorageS3(), validationEnabled);
  }
  public ImageRegistryConfigStorageS3Builder(ImageRegistryConfigStorageS3Fluent<?> fluent,ImageRegistryConfigStorageS3 instance) {
    this(fluent, instance, false);
  }
  public ImageRegistryConfigStorageS3Builder(ImageRegistryConfigStorageS3Fluent<?> fluent,ImageRegistryConfigStorageS3 instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBucket(instance.getBucket()); 
    fluent.withCloudFront(instance.getCloudFront()); 
    fluent.withEncrypt(instance.getEncrypt()); 
    fluent.withKeyID(instance.getKeyID()); 
    fluent.withRegion(instance.getRegion()); 
    fluent.withRegionEndpoint(instance.getRegionEndpoint()); 
    fluent.withVirtualHostedStyle(instance.getVirtualHostedStyle()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageRegistryConfigStorageS3Builder(ImageRegistryConfigStorageS3 instance) {
    this(instance,false);
  }
  public ImageRegistryConfigStorageS3Builder(ImageRegistryConfigStorageS3 instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withBucket(instance.getBucket()); 
    this.withCloudFront(instance.getCloudFront()); 
    this.withEncrypt(instance.getEncrypt()); 
    this.withKeyID(instance.getKeyID()); 
    this.withRegion(instance.getRegion()); 
    this.withRegionEndpoint(instance.getRegionEndpoint()); 
    this.withVirtualHostedStyle(instance.getVirtualHostedStyle()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ImageRegistryConfigStorageS3Fluent<?> fluent;
  Boolean validationEnabled;
  public ImageRegistryConfigStorageS3 build() {
    ImageRegistryConfigStorageS3 buildable = new ImageRegistryConfigStorageS3(fluent.getBucket(),fluent.getCloudFront(),fluent.getEncrypt(),fluent.getKeyID(),fluent.getRegion(),fluent.getRegionEndpoint(),fluent.getVirtualHostedStyle());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
